@@ -208,14 +208,12 @@ retrofitted as unit tests.
 
 =head1 AUTHOR
 
-Copyright (c) 2000 Brian Ewins.
+Copyright (c) 2000-2002, 2005 the PerlUnit Development Team
+(see L<Test::Unit> or the F<AUTHORS> file included in this
+distribution).
 
 All rights reserved. This program is free software; you can
-redistribute it and/or modify it under the same terms as
-Perl itself.
-
-Thanks go to the other PerlUnit framework people: 
-Christian Lemburg, Cayte Lindner, J.E. Fritz, Zhon Johansen.
+redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
